about summary refs log tree commit diff
path: root/math/gen-libm-test.pl
diff options
context:
space:
mode:
Diffstat (limited to 'math/gen-libm-test.pl')
-rwxr-xr-xmath/gen-libm-test.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/math/gen-libm-test.pl b/math/gen-libm-test.pl
index 656c9ceaff..f26a254d2d 100755
--- a/math/gen-libm-test.pl
+++ b/math/gen-libm-test.pl
@@ -675,12 +675,12 @@ sub get_ulps {
 
   if ($type eq 'complex') {
     my ($res);
     # Return 0 instead of BUILD_COMPLEX (0,0)
     if (!exists $results{$test}{'real'}{'ulp'}{$float} &&
 	!exists $results{$test}{'imag'}{'ulp'}{$float}) {
       return "0";
     }
-    $res = 'BUILD_COMPLEX (';
+    $res = 'BUILD_COMPLEX_ULP (';
     $res .= (exists $results{$test}{'real'}{'ulp'}{$float}
 	     ? $results{$test}{'real'}{'ulp'}{$float} : "0");
     $res .= ', ';
@@ -675,12 +675,12 @@ sub get_ulps {
   if ($type eq 'complex') {
     my ($res);
-    # Return 0 instead of BUILD_COMPLEX (0,0)
+    # Return 0 instead of BUILD_COMPLEX_ULP (0,0)
     if (!exists $results{$test}{'real'}{'ulp'}{$float} &&
 	!exists $results{$test}{'imag'}{'ulp'}{$float}) {